CREATE TABLE IF NOT EXISTS CudaManifest(
    id INTEGER, /* Blake3/ca-node of the JSON */
    release_date INTEGER, /* E.g. "2025-03-06" */
    release_label INTEGER, /* E.g. "12.8.1" */
    release_product INTEGER, /* E.g. "cuda" */
    PRIMARY KEY(id),
    FOREIGN KEY(id) REFERENCES Hash(id),
    FOREIGN KEY(release_date) REFERENCES Str(id),
    FOREIGN KEY(release_label) REFERENCES Str(id),
    FOREIGN KEY(release_product) REFERENCES Str(id)
) STRICT;

CREATE TABLE IF NOT EXISTS CudaArtifact(
    manifest INTEGER NOT NULL,
    name INTEGER, /* E.g. "cuda_nvcc"  */
    pname INTEGER, /* E.g. "CUDA NVCC"  */
    license_name INTEGER, /* E.g. "CUDA Toolkit" */
    license_path INTEGER, /* E.g. "cuda_cccl/LICENSE.txt" */
    version INTEGER NOT NULL, /* E.g. "12.8.90" */
    /* Consider making external */
    compat_tag INTEGER, /* E.g. "cuda12" in cudnn */
    sha256 INTEGER,
    md5 INTEGER,
    platform INTEGER, /* E.g. "linux-x86_64" */
    /* E.g. "cuda_cccl/linux-x86_64/cuda_cccl-linux-x86_64-12.8.90-archive.tar.xz" */
    relative_path INTEGER,
    n_bytes INTEGER, /* May be a string in the JSON */
    /* Tempting to have
     * PRIMARY KEY(manifest, name, platform),
     * however that's not unique at least because of `compat_tag`,
     * which might also be `NULL`.
     */
    PRIMARY KEY(sha256, manifest),
    FOREIGN KEY(manifest) REFERENCES CudaManifest(id),
    FOREIGN KEY(manifest) REFERENCES Hash(id),
    FOREIGN KEY(name) REFERENCES Str(id),
    FOREIGN KEY(pname) REFERENCES Str(id),
    FOREIGN KEY(license_name) REFERENCES Str(id),
    FOREIGN KEY(license_path) REFERENCES Str(id),
    FOREIGN KEY(version) REFERENCES Str(id),
    FOREIGN KEY(compat_tag) REFERENCES Str(id),
    FOREIGN KEY(sha256) REFERENCES Hash(id),
    FOREIGN KEY(md5) REFERENCES Hash(id),
    FOREIGN KEY(platform) REFERENCES Str(id),
    FOREIGN KEY(relative_path) REFERENCES Str(id)
) STRICT;

CREATE UNIQUE INDEX IF NOT EXISTS CudaArtifactIdx
ON CudaArtifact(pname, platform, version, compat_tag, name, manifest);
